**********************************
  The :mod:`htsql_mysql` package
**********************************

.. automodule:: htsql_mysql
   :members:
.. automodule:: htsql_mysql.connect
   :members:
.. automodule:: htsql_mysql.domain
   :members:
.. automodule:: htsql_mysql.export
   :members:
.. automodule:: htsql_mysql.introspect
   :members:
.. automodule:: htsql_mysql.split_sql
   :members:

